Learn R Programming

graphclust (version 1.3)

fitSBMcollection: Fit a unique stochastic block model to a collection of networks

Description

fitSBMcollection() is a subversion of graphClustering() where no stopping criterion is applied. So all networks are ultimately merged to a single cluster and considered as i.i.d realisations of a single stochastic block model.

Usage

fitSBMcollection(
  allAdj,
  hyperParam = list(alpha = 0.5, eta = 0.5, zeta = 0.5, lambda = 0.5),
  nbCores = 1
)

Value

list with the following fields: $nodeClusterings is a list with the node labels for each networks, $theta contains the estimated SBM parameter, $ICL is the value of the ICL criterion of the final clustering

Arguments

allAdj

list of adjacency matrices

hyperParam

hyperparameters of prior distributions

nbCores

number of cores for parallelization

Examples

Run this code
theta <- list(pi=c(.5,.5), gamma=matrix((1:4)/8,2,2))
obs <- rCollectSBM(rep(10,4), theta)$listGraphs
res <- fitSBMcollection(obs, nbCores=1)

Run the code above in your browser using DataLab