fitSBMcollection: Fit a unique stochastic block model to a collection of networks
Description
fitSBMcollection() is a subversion of graphClustering() where
no stopping criterion is applied. So all networks are ultimately merged to
a single cluster and considered as i.i.d realisations of a single
stochastic block model.
list with the following fields:
$nodeClusterings is a list with the node labels for each networks,
$theta contains the estimated SBM parameter,
$ICL is the value of the ICL criterion of the final clustering